"use client";

import { AccountInfo } from "@/components/account-info";
import { UserDataContext } from "@/components/providers/userdata-provider";
import { Skeleton } from "@/components/ui/skeleton";
import type { IUserData } from "@/interfaces/userdata.interface";
import {Dispatch, SetStateAction, useContext, useEffect, useState} from "react";

export function AccountDialog() {
	const userContext = useContext(UserDataContext);
	const [isLoaded, setIsLoaded] = useState<boolean>(false);

	if (!userContext?.userData) {
		userContext?.setUserData({
			age: 0,
			city: "Chambéry",
			created_at: "jaj",
			dollarAvailables: 34,
			email: "mherriot@tutanota.com",
			id: "",
			isActive: false,
			lastName: "Herriot",
			pseudo: "Avnyr",
			roleId: "",
			updated_at: "",
			firstName: "Mathis",
		});
	}

	useEffect(() => {
		if (userContext?.userData) {
			setIsLoaded(true);
		}
	}, [userContext?.userData]);

	if (!isLoaded) {
		return <Skeleton className="w-14 h-10 rounded" />;
	}

	return (
		<div>
			<AccountInfo userData={userContext?.userData as IUserData} setUserData={userContext?.setUserData as Dispatch<SetStateAction<IUserData | undefined>>} />
		</div>
	);
}
